@@ -36,7 +36,6 @@ class mul : public expairseq
 	friend class print_order;
 	friend class ex;
 	friend class add;
-	friend class ncmul;
 	friend class power;
 	
 	// other constructors
@@ -54,9 +53,9 @@ public:
 	unsigned precedence() const override {return 50;}
 	bool info(unsigned inf) const override;
 	bool is_polynomial(const ex & var) const override;
-	int degree(const ex & s) const override;
-	int ldegree(const ex & s) const override;
-	ex coeff(const ex & s, int n = 1) const override;
+	numeric degree(const ex & s) const override;
+	numeric ldegree(const ex & s) const override;
+	ex coeff(const ex & s, const ex & n) const override;
 	bool has(const ex & other, unsigned options = 0) const override;
 	ex eval(int level=0) const override;
 	ex evalf(int level=0, PyObject* parent=nullptr) const override;
@@ -68,11 +67,9 @@ public:
 	numeric integer_content() const override;
 	ex smod(const numeric &xi) const override;
 	numeric max_coefficient() const override;
-	exvector get_free_indices() const override;
 	ex conjugate() const override;
 protected:
 	ex derivative(const symbol & s) const override;
-	ex eval_ncmul(const exvector & v) const override;
 	unsigned return_type() const override;
 	tinfo_t return_type_tinfo() const override;
 	ex thisexpairseq(const epvector & v, const numeric & oc, bool do_index_renaming = false) const override;
@@ -115,7 +112,6 @@ protected:
 	void do_print_latex(const print_latex & c, unsigned level) const;
 	void do_print_rat_func(const print_context & c, unsigned level, 
 			bool latex_tags) const;
-	void do_print_csrc(const print_csrc & c, unsigned level) const;
 	void do_print_python_repr(const print_python_repr & c, unsigned level) const override;
 	static bool can_be_further_expanded(const ex & e);
 	std::unique_ptr<epvector> expandchildren(unsigned options) const;
